<template>
  <div>
    <div class="search-list">
      <span class="search-input">
        <span class="search-label">
          <span style="width: 120px;font-size: 14px;line-height: 32px"
          >人员名称：</span
          >
          <el-input
            v-model="entity.name"
            clearable
            placeholder="请输入"
            size="small"
            style="width: 100%;"
            @keyup.enter.native="refreshTable()"
          >
          </el-input>
        </span>
        <el-button size="small" style="margin-left: 10px" @click="refresh()"
        >重 置</el-button
        >
        <el-button size="small" type="primary" @click="refreshTable()"
        >查 询</el-button
        >
      </span>
      <span>
        <el-button
          :loading="outLoading"
          size="small"
          type="primary"
          @click="handleDown"
        >导出</el-button
        >
        <el-button size="small" type="primary" @click="selectUserDia = true"
        >新建</el-button
        >
      </span>
    </div>
    <div class="search-table">
      <el-table
        v-loading="tableLoading"
        :data="tableData"
        border
        height="calc(100vh - 20em)"
        style="width: 100%;"
      >
        <el-table-column align="center" label="序号" type="index" width="60"></el-table-column>
        <el-table-column label="员工编号" prop="account" width="150"></el-table-column>
        <el-table-column label="姓名" prop="name" width="120"></el-table-column>
        <el-table-column label="入集团时间" prop="groupTime" width="120"></el-table-column>
        <el-table-column label="籍贯" prop="nativePlace" width="120"></el-table-column>
        <el-table-column label="证件号码" prop="identityCard" show-overflow-tooltip width="300"></el-table-column>
        <el-table-column label="证件地址" prop="idAddress" show-overflow-tooltip width="100"></el-table-column>
        <el-table-column label="手机号" prop="telephone" show-overflow-tooltip width="100"></el-table-column>
        <el-table-column label="毕业院校" prop="graduatedInstitutions1" width="100"></el-table-column>
        <el-table-column label="所学专业" prop="major1" width="100"></el-table-column>
        <el-table-column label="毕业时间" prop="graduationTime1" width="100"></el-table-column>
        <el-table-column label="最高学历" prop="officialAcademicRedentials" width="100"></el-table-column>
        <el-table-column label="最高学位" prop="highestDegree" width="100"></el-table-column>
        <el-table-column label="职称" prop="professionalTitle" width="100"></el-table-column>
        <el-table-column label="紧急联系人" prop="emergencyContact" width="120"></el-table-column>
        <el-table-column label="紧急联系电话" prop="emergencyContactPhone" width="120"></el-table-column>
        <el-table-column fixed="right" label="操作" width="140">
          <template slot-scope="scope">
            <el-button size="small" type="text" @click="downPerson(scope.row)">下载</el-button>
            <el-button
              size="small"
              type="text"
              @click="$emit('updatePerson', scope.row)"
            >编辑
            </el-button>
            <el-button size="small" type="text" @click="deletePerson(scope.row)"
            >删除
            </el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination
        :current-page="1"
        :current-page.sync="page.current"
        :page-size="page.size"
        :page-sizes="[10, 20, 30, 50, 100]"
        :total="page.total"
        layout="->,total, sizes, prev, pager, next, jumper"
        style="margin-top: 16px"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
      >
      </el-pagination>
    </div>
    <el-dialog :visible.sync="selectUserDia" title="选择用户" width="70%">
      <div class="search" style="margin-bottom: 9px;">
        <div class="search_thing">
          <div class="search_label">用户名：</div>
          <div class="search_input">
            <el-input
              v-model="addUserTableInfo.entity.name"
              clearable
              placeholder="请输入"
              size="small"
              @keyup.enter.native="$refs.ValueTable.selectList()"
            ></el-input>
          </div>
        </div>
      </div>
      <div v-if="selectUserDia" class="body" style="height: 60vh;">
        <ValueTable
          ref="ValueTable"
          :componentData="addUserTableInfo"
          :url="$api.user.selectUserList"
        />
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button @click="selectUserDia = false">取 消</el-button>
        <el-button type="primary" @click="selectUser">确 定</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import ValueTable from '../../tool/value-table.vue';

export default {
  name: 'PersonnelList',
  // import 引入的组件需要注入到对象中才能使用
  components: { ValueTable },
  props: {
    departId: {
      type: Number,
      default: () => {
        return null;
      }
    },
    isDepartment: {
      type: Boolean,
      default: false
    },
    currentCompaniesList: {
      type: Array,
      default: []
    }
  },
  data() {
    // 这里存放数据
    return {
      page: {
        size: 20,
        current: 1,
      },
      outLoading: false,
      tableLoading: false,
      tableData: [], // 人员总列表数据
      selectUserDia: false, // 添加人员弹框
      entity: {
        name: '',
        orderBy: {
          field: 'id',
          order: 'asc'
        }
      },
      addUserTableInfo: {
        name: null,
        entity: {
          isCustom: 0,
          orderBy: {
            field: 'id',
            order: 'asc'
          }
        },
        isIndex: true,
        showSelect: true,
        select: true,
        do: [],
        tagField: {
          state: {
            select: [
              {
                value: 1,
                type: 'success',
                label: '启用'
              },
              {
                value: 0,
                type: 'danger',
                label: '停用'
              }
            ]
          }
        },
        selectField: {},
        upUserDepardLimsIdPower: true
      },
    };
  },
  mounted() {
    this.refreshTable();
  },
  // 方法集合
  methods: {
    /**
     * @desc 获取设备id
     */
    // 重置
    refresh() {
      this.page = {
        size: 20,
        current: 1,
      };
      this.entity.name = ''
      this.refreshTable();
    },
    // 查询人员列表数据
    refreshTable(entity, type) {
      try {
        this.tableLoading = true;
        this.entity.departLimsId = this.departId;
        this.$axios.get(
          this.$api.personnel.basicInformationOfPersonnelSelectPage
          + '?size=' + this.page.size
          + '&current=' + this.page.current
          + '&departmentId=' + this.entity.departLimsId
          + '&name=' + this.entity.name
        )
          .then(res => {
            this.tableLoading = false;
            if (res.code === 201) {
              return;
            }
            this.page.total = res.data.total;
            this.tableData = res.data.records;
          });
      } catch (e) {
        this.tableLoading = false;
      }
    },
    // 删除人员
    deletePerson(row) {
      this.$confirm('是否删除当前数据?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(() => {
          this.$axios
            .post(this.$api.user.delUserDepardLimsId + '?id=' + row.userId)
            .then(res => {
              if (res.code === 201) {
                return;
              }
              this.$message.success('删除成功');
              this.refreshTable();
            })
            .catch(e => {
              this.$message.error('删除失败');
            });
        })
        .catch(() => {
        });
    },
    handleSizeChange(val) {
      this.page.size = val;
      this.refreshTable();
    },
    handleCurrentChange(val) {
      this.page.current = val;
      this.refreshTable();
    },
    selectUser() {
      if (!this.currentCompaniesList.length > 0) {
        this.$message.warning("请选择部门！")
        return;
      }
      let selects = this.$refs.ValueTable.multipleSelection;
      if (selects.length == 0) {
        this.$message.error('未选择数据');
        return;
      }
      let ids = [];
      selects.forEach(a => {
        ids.push(a.id);
      });
      let str = '';
      this.currentCompaniesList.forEach(a => {
        if (a) {
          str += a + ',';
        }
      });
      this.selectUserDia = false;
      this.$axios.post(this.$api.user.upUserDepardLimsId, {
        ids: JSON.stringify(ids),
        id: str
      }).then(res => {
        if (res.code === 201) {
          return;
        }
        this.$message.success('添加成功');
        this.refreshTable();
      });
      this.$emit('refreshTree')
    },
    handleDown() {
      this.outLoading = true;
      let entity = this.HaveJson(this.entity)
      delete entity.orderBy;
      this.$axios.post(
          this.$api.personPostAuthorizationRecord.exportPersonBasicInfo,
          {
            entity: entity
          },
          {
            headers: {
              'Content-Type': 'application/json'
            },
            responseType: "blob"
          }
        )
        .then(res => {
          this.outLoading = false;
          if (res.code === 201) {
            return;
          }
          const blob = new Blob([res],{ type: 'application/octet-stream' });
          //将Blob 对象转换成字符串
          let reader = new FileReader();
          reader.readAsText(blob, 'utf-8');
          reader.onload = () => {
            try {
              let result = JSON.parse(reader.result);
              if (result.message) {
                this.$message.error(result.message);
              } else {
                const url = URL.createObjectURL(blob);
                const link = document.createElement('a');
                link.href = url;
                link.download = '人员信息.xlsx';
                link.click();
                this.$message.success('导出成功')
              }
            } catch (err) {
              console.log(err);
              const url = URL.createObjectURL(blob);
              const link = document.createElement('a');
              link.href = url;
              link.download = '人员信息.xlsx';
              link.click();
              this.$message.success('导出成功')
            }
          }
        });
    },
    downPerson(row){
      this.$axios.post(
          this.$api.personPostAuthorizationRecord.exportPersonBasicInfoById+'?id=' + row.userId,
          {
            id: row.userId
          }
        )
        .then(res => {
          if (res.code === 201) {
            return;
          }
          this.$message.success('下载成功')
          try {
            let url = res.message;
            const link = document.createElement('a');
            link.href = this.javaApi + '/word/'+ url;
            // link.target = '_blank';
            document.body.appendChild(link);
            link.click();
          } catch (error) {

          }
        });
    }
  },
  watch: {
    departId: {
      handler(newId, oldId) {
        if (newId) {
          this.page.current = 1
          this.refreshTable();
        }
      }
    }
  }
};
</script>

<style scoped>
.search-list {
  padding: 0 16px 16px;
  display: flex;
  justify-content: space-between;
}

.search-table {
  padding: 0 16px;
}

.search-input {
  display: flex;
}

.search-label {
  display: flex;
}
</style>
